@@ -143,7 +143,6 @@ def test_profisioner_config_private_member(instance):  # type: ignore[no-untyped
 def test_default_config_options_property(instance):  # type: ignore[no-untyped-def]  # noqa: ANN201, D103
     x = {
         "defaults": {
-            "ansible_managed": "Ansible managed: Do NOT edit this file manually!",
             "display_failed_stderr": True,
             "forks": 50,
             "host_key_checking": False,
@@ -188,7 +187,6 @@ def test_provisioner_name_property(instance):  # type: ignore[no-untyped-def]  #
 def test_config_options_property(instance):  # type: ignore[no-untyped-def]  # noqa: ANN201, D103
     x = {
         "defaults": {
-            "ansible_managed": "Ansible managed: Do NOT edit this file manually!",
             "display_failed_stderr": True,
             "foo": "bar",
             "forks": 50,
@@ -686,8 +684,12 @@ def test_remove_vars_symlinks(instance):  # type: ignore[no-untyped-def]  # noqa
 
     source_group_vars = os.path.join(inventory_dir, os.path.pardir, "group_vars")  # noqa: PTH118
     target_group_vars = os.path.join(inventory_dir, "group_vars")  # noqa: PTH118
-    os.mkdir(source_group_vars)  # noqa: PTH102
-    os.symlink(source_group_vars, target_group_vars)
+    path = Path(source_group_vars)
+    path.parent.mkdir(parents=True, exist_ok=True)
+    if not path.is_symlink():
+        if path.exists():
+            path.unlink()
+        path.symlink_to(target_group_vars)
 
     instance._remove_vars()
 
